# marketify
micro-library for pulling market data from exchanges and doing something with it

## Rest
Client class for pulling market data from RESTful APIs

## Websocket
Client class for pulling market data from websocket APIs

## Runner
Class that asynchronously runs a collection of tasks